@@ -41,8 +41,8 @@ PuzzlePrinter::PuzzlePrinter(QWidget * parent)
 	:
 	QObject(parent),
 	m_parent(parent),
-	m_printer(0),
-	m_p(0),
+	m_printer(nullptr),
+	m_p(nullptr),
 	m_quadrant(0),
 	m_across(2),
 	m_down(2)
@@ -98,11 +98,11 @@ void PuzzlePrinter::print (const ksudoku::Game & game)
 
 void PuzzlePrinter::endPrint()
 {
-    if (m_p != 0) {
+    if (m_p != nullptr) {
         // The current print output goes to the printer when the painter ends.
         m_p->end();
         delete m_p;
-        m_p = 0;
+        m_p = nullptr;
         m_quadrant = 0;
         KMessageBox::information (m_parent,
             i18n ("KSudoku has sent output to your printer."));
@@ -115,17 +115,17 @@ bool PuzzlePrinter::setupOutputDevices (int leastCellsToFit, int puzzleWidth)
     // (if required) we can print several puzzles per page and defer printing
     // until the page is full or KSudoku terminates and the painter ends itself.
     // NOTE: Must create painter before using functions like m_printer->width().
-    if (m_printer == 0) {
+    if (m_printer == nullptr) {
         m_printer = new QPrinter (QPrinter::HighResolution);
-        QPrintDialog * dialog = new QPrintDialog(m_printer, m_parent);
+        auto * dialog = new QPrintDialog(m_printer, m_parent);
         dialog->setWindowTitle(i18n("Print Sudoku Puzzle"));
         if (dialog->exec() != QDialog::Accepted) {
             delete m_printer;
-            m_printer = 0;
+            m_printer = nullptr;
             return false;
         }
     }
-    if (m_p == 0) {
+    if (m_p == nullptr) {
         m_p = new QPainter (m_printer);	// Start a new print job.
     }
     m_printMulti = Settings::printMulti();
@@ -291,8 +291,8 @@ void PuzzlePrinter::drawCell (int posX, int posY, int edge)
 
 void PuzzlePrinter::drawValues (const ksudoku::Game& game, const SKGraph* graph)
 {
-    const QString labels = (graph->base() <= 3) ? "123456789" :
-                                                  "ABCDEFGHIJKLMNOPQRSTUVWXY";
+    const QString labels = (graph->base() <= 3) ? QStringLiteral("123456789") :
+                               QStringLiteral("ABCDEFGHIJKLMNOPQRSTUVWXY");
     // Set font size 60% height of cell.
     QFont f = m_p->font();
     f.setPixelSize ((m_sCell * 6) / 10);
@@ -414,7 +414,7 @@ void PuzzlePrinter::drawCageLabel (const SKGraph* graph, int n,
     QFontMetrics fm(f);
     int w = fm.boundingRect(cLabel).width();
     int a = fm.ascent();
-    int m = (fm.boundingRect(QChar('1')).width()+1)/3;	// Left margin = 1/3 width of '1'.
+    int m = (fm.boundingRect(QLatin1Char('1')).width()+1)/3;	// Left margin = 1/3 width of '1'.
 
     if (killerStyle) {
 	// Cover part of the dashed line, to make a background for the text.
